@@ -8,7 +8,7 @@ import pandas as pd
 import numpy as np
 import xarray as xr
 
-from .dataset import _get_dataset
+from .dataset import get_dataset
 
 
 logger = logging.getLogger(__name__)
@@ -91,7 +91,7 @@ class GordoBaseDataset(metaclass=ABCMeta):
         """
         Construct the dataset using a config from :func:`~GordoBaseDataset.to_dict`
         """
-        return _get_dataset(config)
+        return get_dataset(config)
 
     def get_metadata(self):
         """
